## Additional training curves for CLIP on Conceptual Captions

# Zero shot accuracy
![](/docs/clip_zeroshot.png)

# Training loss curve
![](/docs/clip_loss.png)

# Validation loss curve
![](/docs/clip_val_loss.png)

# Validation recall
![](/docs/clip_recall.png)